@@ -8,12 +8,13 @@ import datetime
 import datetime as dt
 import logging
 import os
-
+import time
 import redis
 
 from redisbench_admin.run.aibench_run_inference_redisai_vision.aibench_run_inference_redisai_vision import (
     prepare_aibench_benchmark_command,
 )
+from redisbench_admin.run.ftsb.ftsb import prepare_ftsb_benchmark_command
 from redisbench_admin.run.redis_benchmark.redis_benchmark import (
     prepare_redis_benchmark_command,
 )
@@ -56,73 +57,37 @@ def prepare_benchmark_parameters(
 ):
     command_arr = None
     command_str = None
-    for entry in benchmark_config["clientconfig"]:
-        if "parameters" in entry:
-            if "redis-benchmark" in benchmark_tool:
-                command_arr, command_str = prepare_redis_benchmark_command(
-                    benchmark_tool, server_private_ip, server_plaintext_port, entry
-                )
-                if isremote is True:
-                    redirect_file = "> {}".format(remote_results_file)
-                    command_arr.append(redirect_file)
-                    command_str = command_str + " " + redirect_file
-
-            if "redisgraph-benchmark-go" in benchmark_tool:
-                if isremote is True:
-                    benchmark_tool = "/tmp/redisgraph-benchmark-go"
-                command_arr, command_str = prepare_redisgraph_benchmark_go_command(
+    # v0.1 to 0.3 spec
+    if type(benchmark_config["clientconfig"]) == list:
+        for entry in benchmark_config["clientconfig"]:
+            if "parameters" in entry:
+                command_arr, command_str = prepare_benchmark_parameters_specif_tooling(
                     benchmark_tool,
-                    server_private_ip,
-                    server_plaintext_port,
-                    entry,
-                    remote_results_file,
-                    isremote,
-                )
-
-            if "ycsb" in benchmark_tool:
-                if isremote is True:
-                    benchmark_tool = (
-                        "/tmp/ycsb-redisearch-binding-0.18.0-SNAPSHOT/bin/ycsb"
-                    )
-                    current_workdir = "/tmp/ycsb-redisearch-binding-0.18.0-SNAPSHOT"
-                command_arr, command_str = prepare_ycsb_benchmark_command(
-                    benchmark_tool,
-                    server_private_ip,
-                    server_plaintext_port,
-                    entry,
-                    current_workdir,
-                )
-            if "tsbs_" in benchmark_tool:
-                input_data_file = None
-                if isremote is True:
-                    benchmark_tool = "/tmp/{}".format(benchmark_tool)
-                    input_data_file = "/tmp/input.data"
-                (command_arr, command_str,) = prepare_tsbs_benchmark_command(
-                    benchmark_tool,
-                    server_private_ip,
-                    server_plaintext_port,
-                    entry,
-                    current_workdir,
-                    remote_results_file,
-                    input_data_file,
-                    isremote,
                     cluster_api_enabled,
-                )
-            if "aibench_" in benchmark_tool:
-                input_data_file = None
-                if isremote is True:
-                    benchmark_tool = "/tmp/{}".format(benchmark_tool)
-                    input_data_file = "/tmp/input.data"
-                (command_arr, command_str,) = prepare_aibench_benchmark_command(
-                    benchmark_tool,
-                    server_private_ip,
-                    server_plaintext_port,
-                    entry,
+                    command_arr,
+                    command_str,
                     current_workdir,
-                    remote_results_file,
-                    input_data_file,
+                    entry,
                     isremote,
+                    remote_results_file,
+                    server_plaintext_port,
+                    server_private_ip,
                 )
+    # v0.4 spec
+    elif type(benchmark_config["clientconfig"]) == dict:
+        entry = benchmark_config["clientconfig"]
+        command_arr, command_str = prepare_benchmark_parameters_specif_tooling(
+            benchmark_tool,
+            cluster_api_enabled,
+            command_arr,
+            command_str,
+            current_workdir,
+            entry,
+            isremote,
+            remote_results_file,
+            server_plaintext_port,
+            server_private_ip,
+        )
     printed_command_str = command_str
     printed_command_arr = command_arr
     if len(command_str) > 200:
@@ -136,6 +101,98 @@ def prepare_benchmark_parameters(
     return command_arr, command_str
 
 
+def prepare_benchmark_parameters_specif_tooling(
+    benchmark_tool,
+    cluster_api_enabled,
+    command_arr,
+    command_str,
+    current_workdir,
+    entry,
+    isremote,
+    remote_results_file,
+    server_plaintext_port,
+    server_private_ip,
+):
+    if "redis-benchmark" in benchmark_tool:
+        command_arr, command_str = prepare_redis_benchmark_command(
+            benchmark_tool, server_private_ip, server_plaintext_port, entry
+        )
+        if isremote is True:
+            redirect_file = "> {}".format(remote_results_file)
+            command_arr.append(redirect_file)
+            command_str = command_str + " " + redirect_file
+    if "redisgraph-benchmark-go" in benchmark_tool:
+        if isremote is True:
+            benchmark_tool = "/tmp/redisgraph-benchmark-go"
+        command_arr, command_str = prepare_redisgraph_benchmark_go_command(
+            benchmark_tool,
+            server_private_ip,
+            server_plaintext_port,
+            entry,
+            remote_results_file,
+            isremote,
+        )
+    if "ycsb" in benchmark_tool:
+        if isremote is True:
+            benchmark_tool = "/tmp/ycsb-redisearch-binding-0.18.0-SNAPSHOT/bin/ycsb"
+            current_workdir = "/tmp/ycsb-redisearch-binding-0.18.0-SNAPSHOT"
+        command_arr, command_str = prepare_ycsb_benchmark_command(
+            benchmark_tool,
+            server_private_ip,
+            server_plaintext_port,
+            entry,
+            current_workdir,
+        )
+    if "tsbs_" in benchmark_tool:
+        input_data_file = None
+        if isremote is True:
+            benchmark_tool = "/tmp/{}".format(benchmark_tool)
+            input_data_file = "/tmp/input.data"
+        (command_arr, command_str,) = prepare_tsbs_benchmark_command(
+            benchmark_tool,
+            server_private_ip,
+            server_plaintext_port,
+            entry,
+            current_workdir,
+            remote_results_file,
+            input_data_file,
+            isremote,
+            cluster_api_enabled,
+        )
+    if "ftsb_" in benchmark_tool:
+        input_data_file = None
+        if isremote is True:
+            benchmark_tool = "/tmp/{}".format(benchmark_tool)
+            input_data_file = "/tmp/input.data"
+        (command_arr, command_str,) = prepare_ftsb_benchmark_command(
+            benchmark_tool,
+            server_private_ip,
+            server_plaintext_port,
+            entry,
+            current_workdir,
+            remote_results_file,
+            input_data_file,
+            isremote,
+            cluster_api_enabled,
+        )
+    if "aibench_" in benchmark_tool:
+        input_data_file = None
+        if isremote is True:
+            benchmark_tool = "/tmp/{}".format(benchmark_tool)
+            input_data_file = "/tmp/input.data"
+        (command_arr, command_str,) = prepare_aibench_benchmark_command(
+            benchmark_tool,
+            server_private_ip,
+            server_plaintext_port,
+            entry,
+            current_workdir,
+            remote_results_file,
+            input_data_file,
+            isremote,
+        )
+    return command_arr, command_str
+
+
 def run_remote_benchmark(
     client_public_ip,
     username,
@@ -188,6 +245,8 @@ def common_exporter_logic(
     tf_github_repo,
     tf_triggering_env,
     artifact_version="N/A",
+    metadata_tags={},
+    build_variant_name=None,
 ):
     per_version_time_series_dict = None
     per_branch_time_series_dict = None
@@ -197,25 +256,31 @@ def common_exporter_logic(
         datapoints_timestamp = parse_exporter_timemetric(
             exporter_timemetric_path, results_dict
         )
-
-        # extract per branch datapoints
-        (
-            ok,
-            per_version_time_series_dict,
-        ) = extract_perversion_timeseries_from_results(
-            datapoints_timestamp,
-            metrics,
-            results_dict,
-            artifact_version,
-            tf_github_org,
-            tf_github_repo,
-            deployment_type,
-            test_name,
-            tf_triggering_env,
-        )
-        if ok:
-            # push per-version data
-            push_data_to_redistimeseries(rts, per_version_time_series_dict)
+        if (
+            artifact_version is not None
+            and artifact_version != ""
+            and artifact_version != "N/A"
+        ):
+            # extract per-version datapoints
+            (
+                ok,
+                per_version_time_series_dict,
+            ) = extract_perversion_timeseries_from_results(
+                datapoints_timestamp,
+                metrics,
+                results_dict,
+                artifact_version,
+                tf_github_org,
+                tf_github_repo,
+                deployment_type,
+                test_name,
+                tf_triggering_env,
+                metadata_tags,
+                build_variant_name,
+            )
+            if ok:
+                # push per-version data
+                push_data_to_redistimeseries(rts, per_version_time_series_dict)
         if tf_github_branch is not None and tf_github_branch != "":
             # extract per branch datapoints
             ok, per_branch_time_series_dict = extract_perbranch_timeseries_from_results(
@@ -228,6 +293,8 @@ def common_exporter_logic(
                 deployment_type,
                 test_name,
                 tf_triggering_env,
+                metadata_tags,
+                build_variant_name,
             )
             if ok:
                 # push per-branch data
@@ -329,6 +396,8 @@ def get_setup_type_and_primaries_count(setup_settings):
 def merge_default_and_config_metrics(
     benchmark_config, default_metrics, exporter_timemetric_path
 ):
+    if default_metrics is None:
+        default_metrics = []
     metrics = default_metrics
     if "exporter" in benchmark_config:
         extra_metrics = parse_exporter_metrics_definition(benchmark_config["exporter"])
@@ -360,6 +429,41 @@ def run_redis_pre_steps(benchmark_config, r, required_modules):
             execute_init_commands_duration_seconds
         )
     )
+    if "search" in module_names:
+        logging.info(
+            "Given redisearch was detected, checking for any index that is still indexing."
+        )
+        loading_indices = r.execute_command("ft._list")
+        logging.info("Detected {} indices.".format(len(loading_indices)))
+        while len(loading_indices) > 0:
+            logging.info(
+                "There are still {} indices loading. {}".format(
+                    len(loading_indices), loading_indices
+                )
+            )
+            for index_pos, fts_indexname in enumerate(loading_indices, start=0):
+                if type(fts_indexname) == bytes:
+                    fts_indexname = fts_indexname.decode()
+                ft_info = r.execute_command("ft.info {}".format(fts_indexname))
+                is_indexing = None
+                percent_indexed = "0.0"
+                for arraypos, arrayval in enumerate(ft_info, start=0):
+                    if arrayval == b"percent_indexed" or arrayval == "percent_indexed":
+                        percent_indexed = ft_info[arraypos + 1]
+                    if arrayval == b"indexing" or arrayval == "indexing":
+                        is_indexing = ft_info[arraypos + 1]
+
+                logging.info(
+                    "indexing={} ; percent_indexed={}.".format(
+                        is_indexing, percent_indexed
+                    )
+                )
+                if is_indexing == "0" or is_indexing == b"0" or is_indexing == 0:
+                    loading_indices.pop(index_pos)
+
+            time.sleep(5)
+        logging.info("Loaded all secondary indices.")
+
     return artifact_versions[0]
 
 
