@@ -29,6 +29,8 @@ def redistimeseries_results_logic(
     tf_github_org,
     tf_github_repo,
     tf_triggering_env,
+    metadata_tags={},
+    build_variant_name=None,
 ):
     # check which metrics to extract
     exporter_timemetric_path, metrics = merge_default_and_config_metrics(
@@ -46,6 +48,8 @@ def redistimeseries_results_logic(
         tf_github_repo,
         tf_triggering_env,
         artifact_version,
+        metadata_tags,
+        build_variant_name,
     )
     return per_version_time_series_dict, per_branch_time_series_dict
 
@@ -163,7 +167,7 @@ def add_standardized_metric_byversion(
 
 
 def timeseries_test_sucess_flow(
-    args,
+    push_results_redistimeseries,
     artifact_version,
     benchmark_config,
     benchmark_duration_seconds,
@@ -182,7 +186,7 @@ def timeseries_test_sucess_flow(
     tf_triggering_env,
     tsname_project_total_success,
 ):
-    if args.push_results_redistimeseries:
+    if push_results_redistimeseries:
         logging.info("Pushing results to RedisTimeSeries.")
         redistimeseries_results_logic(
             artifact_version,
@@ -236,30 +240,31 @@ def timeseries_test_sucess_flow(
                     tf_github_repo,
                     tf_triggering_env,
                 )
-            add_standardized_metric_byversion(
-                "benchmark_duration",
-                benchmark_duration_seconds,
-                artifact_version,
-                deployment_type,
-                rts,
-                start_time_ms,
-                test_name,
-                tf_github_org,
-                tf_github_repo,
-                tf_triggering_env,
-            )
-            add_standardized_metric_byversion(
-                "dataset_load_duration",
-                dataset_load_duration_seconds,
-                artifact_version,
-                deployment_type,
-                rts,
-                start_time_ms,
-                test_name,
-                tf_github_org,
-                tf_github_repo,
-                tf_triggering_env,
-            )
+            if artifact_version is not None and artifact_version != "":
+                add_standardized_metric_byversion(
+                    "benchmark_duration",
+                    benchmark_duration_seconds,
+                    artifact_version,
+                    deployment_type,
+                    rts,
+                    start_time_ms,
+                    test_name,
+                    tf_github_org,
+                    tf_github_repo,
+                    tf_triggering_env,
+                )
+                add_standardized_metric_byversion(
+                    "dataset_load_duration",
+                    dataset_load_duration_seconds,
+                    artifact_version,
+                    deployment_type,
+                    rts,
+                    start_time_ms,
+                    test_name,
+                    tf_github_org,
+                    tf_github_repo,
+                    tf_triggering_env,
+                )
         except redis.exceptions.ResponseError as e:
             logging.warning(
                 "Error while updating secondary data structures {}. ".format(
