@@ -59,6 +59,7 @@ from redisbench_admin.utils.remote import (
     get_run_full_filename,
     get_overall_dashboard_keynames,
     check_ec2_env,
+    execute_remote_commands,
 )
 
 from redisbench_admin.utils.utils import (
@@ -199,6 +200,19 @@ def run_remote_command_logic(args, project_name, project_version):
                         # after we've created the env, even on error we should always teardown
                         # in case of some unexpected error we fail the test
                         try:
+                            # ensure /tmp folder is free of benchmark data from previous runs
+                            remote_working_folder = "/tmp"
+                            execute_remote_commands(
+                                server_public_ip,
+                                username,
+                                private_key,
+                                [
+                                    "rm -rf {}/*.log".format(remote_working_folder),
+                                    "rm -rf {}/*.rdb".format(remote_working_folder),
+                                    "rm -rf {}/*.out".format(remote_working_folder),
+                                    "rm -rf {}/*.data".format(remote_working_folder),
+                                ],
+                            )
                             _, _, testcase_start_time_str = get_start_time_vars()
                             logname = "{}_{}.log".format(
                                 test_name, testcase_start_time_str
@@ -217,8 +231,13 @@ def run_remote_command_logic(args, project_name, project_version):
                             )
 
                             cluster_api_enabled = False
+                            cluster_start_port = 20000
                             # setup Redis
                             if setup_type == "oss-cluster":
+                                logging.error(
+                                    "Remote cluster is still not implemented =(. We're working hard to get it ASAP =)!!"
+                                )
+                                continue
                                 cluster_api_enabled = True
                                 spin_up_redis_cluster_remote_redis(
                                     benchmark_config,
@@ -233,19 +252,21 @@ def run_remote_command_logic(args, project_name, project_version):
                                     redis_configuration_parameters,
                                     dbdir_folder,
                                     shard_count,
-                                    args.port,
+                                    cluster_start_port,
                                 )
                                 dataset_load_start_time = datetime.datetime.now()
 
                                 # we use node 0 for the checks
                                 local_redis_conn = ssh_tunnel_redisconn(
-                                    args.port,
+                                    cluster_start_port,
                                     server_private_ip,
                                     server_public_ip,
                                     username,
                                 )
                                 r_conns = []
-                                for p in range(args.port, args.port + shard_count):
+                                for p in range(
+                                    cluster_start_port, cluster_start_port + shard_count
+                                ):
                                     local_redis_conn, ssh_tunnel = ssh_tunnel_redisconn(
                                         p,
                                         server_private_ip,
@@ -257,7 +278,7 @@ def run_remote_command_logic(args, project_name, project_version):
                                     )
 
                             if setup_type == "oss-standalone":
-                                full_logfile = spin_up_standalone_remote_redis(
+                                full_logfile, dataset = spin_up_standalone_remote_redis(
                                     benchmark_config,
                                     server_public_ip,
                                     username,
@@ -280,6 +301,7 @@ def run_remote_command_logic(args, project_name, project_version):
                             result = wait_for_conn(
                                 local_redis_conn, dataset_load_timeout_secs
                             )
+                            logging.info("Starting dataset loading...")
                             dataset_load_end_time = datetime.datetime.now()
                             if result is True:
                                 logging.info("Redis available")
@@ -299,12 +321,16 @@ def run_remote_command_logic(args, project_name, project_version):
                             )
 
                             if setup_type == "oss-cluster":
+                                contains_rdb = False
+                                if dataset is not None:
+                                    contains_rdb = True
                                 startup_nodes = cluster_init_steps(
                                     args,
                                     clusterconfig,
                                     local_module_file,
                                     r_conns,
                                     shard_count,
+                                    contains_rdb,
                                 )
 
                                 rc = RedisCluster(
@@ -321,8 +347,6 @@ def run_remote_command_logic(args, project_name, project_version):
                                 benchmark_config, local_redis_conn, required_modules
                             )
 
-                            ssh_tunnel.close()  # Close the tunnel
-
                             (
                                 benchmark_min_tool_version,
                                 benchmark_min_tool_version_major,
@@ -331,6 +355,7 @@ def run_remote_command_logic(args, project_name, project_version):
                                 benchmark_tool,
                                 benchmark_tool_source,
                                 _,
+                                _,
                             ) = extract_benchmark_tool_settings(benchmark_config)
                             benchmark_tools_sanity_check(args, benchmark_tool)
                             # setup the benchmark tool
@@ -391,6 +416,10 @@ def run_remote_command_logic(args, project_name, project_version):
                                 command_str,
                             )
                             benchmark_end_time = datetime.datetime.now()
+
+                            logging.info("Shutting down remote redis.")
+                            local_redis_conn.shutdown(save=False)
+                            ssh_tunnel.close()  # Close the tunnel
                             if remote_run_result is False:
                                 failed_remote_run_artifact_store(
                                     args,
@@ -437,7 +466,7 @@ def run_remote_command_logic(args, project_name, project_version):
                                 )
 
                             timeseries_test_sucess_flow(
-                                args,
+                                args.push_results_redistimeseries,
                                 artifact_version,
                                 benchmark_config,
                                 benchmark_duration_seconds,
