@@ -30,6 +30,7 @@ from redisbench_admin.utils.utils import (
 # environment variables
 PERFORMANCE_RTS_PUSH = bool(os.getenv("PUSH_RTS", False))
 PERFORMANCE_RTS_AUTH = os.getenv("PERFORMANCE_RTS_AUTH", None)
+PERFORMANCE_RTS_USER = os.getenv("PERFORMANCE_RTS_USER", None)
 PERFORMANCE_RTS_HOST = os.getenv("PERFORMANCE_RTS_HOST", "localhost")
 PERFORMANCE_RTS_PORT = os.getenv("PERFORMANCE_RTS_PORT", 6379)
 TERRAFORM_BIN_PATH = os.getenv("TERRAFORM_BIN_PATH", "terraform")
@@ -163,7 +164,7 @@ def check_dataset_remote_requirements(
             remote_dataset_file,
             None,
         )
-    return res
+    return res, dataset, fullpath, tmppath
 
 
 def setup_remote_environment(
@@ -239,39 +240,53 @@ def tf_output_or_none(tf_output, output_prop):
 
 
 def extract_git_vars(path=None, github_url=None):
-    if path is None:
-        path = get_git_root(".")
-    github_repo = Repo(path)
-    if github_url is None:
-        github_url = github_repo.remotes[0].config_reader.get("url")
-    if "/" in github_url[-1:]:
-        github_url = github_url[:-1]
-    if "http" in github_url:
-        github_org_name = github_url.split("/")[-2]
-        github_repo_name = github_url.split("/")[-1].split(".")[0]
-    else:
-        github_url = github_url.replace(".git", "")
-        github_org_name = github_url.split(":")[1].split("/")[0]
-        github_repo_name = github_url.split(":")[1].split("/")[1]
-    github_sha = github_repo.head.object.hexsha
-    github_branch = None
-    github_branch_detached = False
-    try:
-        github_branch = github_repo.active_branch
-    except TypeError as e:
-        logging.warning(
-            "Unable to detected github_branch. caught the following error: {}".format(
-                e.__str__()
-            )
-        )
-        github_branch_detached = True
-
+    github_org_name = None
+    github_repo_name = None
+    github_sha = None
     github_actor = None
+    github_branch = None
+    github_branch_detached = None
     try:
-        github_actor = github_repo.config_reader().get_value("user", "name")
-    except configparser.NoSectionError as e:
+        if path is None:
+            path = get_git_root(".")
+        github_repo = Repo(path)
+        if github_url is None:
+            github_url = github_repo.remotes[0].config_reader.get("url")
+        if "/" in github_url[-1:]:
+            github_url = github_url[:-1]
+        if "http" in github_url:
+            github_org_name = github_url.split("/")[-2]
+            github_repo_name = github_url.split("/")[-1].split(".")[0]
+        else:
+            github_url = github_url.replace(".git", "")
+            github_org_name = github_url.split(":")[1].split("/")[0]
+            github_repo_name = github_url.split(":")[1].split("/")[1]
+        github_sha = github_repo.head.object.hexsha
+        github_branch = None
+        github_branch_detached = False
+        try:
+            github_branch = github_repo.active_branch
+        except TypeError as e:
+            logging.warning(
+                "Unable to detected github_branch. caught the following error: {}".format(
+                    e.__str__()
+                )
+            )
+            github_branch_detached = True
+
+        github_actor = None
+        try:
+            github_actor = github_repo.config_reader().get_value("user", "name")
+        except configparser.NoSectionError as e:
+            logging.warning(
+                "Unable to detected github_actor. caught the following error: {}".format(
+                    e.__str__()
+                )
+            )
+            github_branch_detached = True
+    except git.exc.InvalidGitRepositoryError as e:
         logging.warning(
-            "Unable to detected github_actor. caught the following error: {}".format(
+            "Unable to fill git vars. caught the following error: {}".format(
                 e.__str__()
             )
         )
@@ -481,6 +496,43 @@ def extract_perversion_timeseries_from_results(
     deployment_type: str,
     test_name: str,
     tf_triggering_env: str,
+    metadata_tags={},
+    build_variant_name=None,
+):
+    break_by_key = "version"
+    break_by_str = "by.{}".format(break_by_key)
+    branch_time_series_dict = common_timeseries_extraction(
+        break_by_key,
+        break_by_str,
+        datapoints_timestamp,
+        deployment_type,
+        metrics,
+        project_version,
+        results_dict,
+        test_name,
+        tf_github_org,
+        tf_github_repo,
+        tf_triggering_env,
+        metadata_tags,
+        build_variant_name,
+    )
+    return True, branch_time_series_dict
+
+
+def common_timeseries_extraction(
+    break_by_key,
+    break_by_str,
+    datapoints_timestamp,
+    deployment_type,
+    metrics,
+    project_version,
+    results_dict,
+    test_name,
+    tf_github_org,
+    tf_github_repo,
+    tf_triggering_env,
+    metadata_tags={},
+    build_variant_name=None,
 ):
     branch_time_series_dict = {}
     for jsonpath in metrics:
@@ -489,38 +541,62 @@ def extract_perversion_timeseries_from_results(
         except Exception:
             pass
         finally:
-            metric_name = jsonpath[2:]
             find_res = jsonpath_expr.find(results_dict)
-            if find_res is not None and len(find_res) > 0:
-                metric_value = float(find_res[0].value)
-                # prepare tags
-                # branch tags
-                version_tags = get_project_ts_tags(
-                    tf_github_org, tf_github_repo, deployment_type, tf_triggering_env
-                )
-                version_tags["version"] = project_version
-                version_tags["test_name"] = str(test_name)
-                version_tags["metric"] = str(metric_name)
-                ts_name = get_ts_metric_name(
-                    "by.version",
-                    project_version,
-                    tf_github_org,
-                    tf_github_repo,
-                    deployment_type,
-                    test_name,
-                    tf_triggering_env,
-                    metric_name,
-                )
+            if find_res is not None:
+                use_metric_context_path = False
+                if len(find_res) > 1:
+                    use_metric_context_path = True
+                for metric in find_res:
+                    metric_name = str(metric.path)
+                    metric_value = float(metric.value)
+                    metric_jsonpath = jsonpath
+                    metric_context_path = str(metric.context.path)
+                    if metric_jsonpath[0] == "$":
+                        metric_jsonpath = metric_jsonpath[1:]
+                    if metric_jsonpath[0] == ".":
+                        metric_jsonpath = metric_jsonpath[1:]
 
-                branch_time_series_dict[ts_name] = {
-                    "labels": version_tags.copy(),
-                    "data": {datapoints_timestamp: metric_value},
-                }
+                    # retro-compatible naming
+                    if use_metric_context_path is False:
+                        metric_name = metric_jsonpath
+
+                    # prepare tags
+                    timeserie_tags = get_project_ts_tags(
+                        tf_github_org,
+                        tf_github_repo,
+                        deployment_type,
+                        tf_triggering_env,
+                    )
+                    timeserie_tags[break_by_key] = project_version
+                    timeserie_tags["test_name"] = str(test_name)
+                    timeserie_tags["metric"] = str(metric_name)
+                    timeserie_tags["metric_name"] = metric_name
+                    timeserie_tags["metric_context_path"] = metric_context_path
+                    timeserie_tags["metric_jsonpath"] = metric_jsonpath
+                    for k, v in metadata_tags.items():
+                        timeserie_tags[k] = v
+                    ts_name = get_ts_metric_name(
+                        break_by_str,
+                        project_version,
+                        tf_github_org,
+                        tf_github_repo,
+                        deployment_type,
+                        test_name,
+                        tf_triggering_env,
+                        metric_name,
+                        metric_context_path,
+                        use_metric_context_path,
+                        build_variant_name,
+                    )
+                    branch_time_series_dict[ts_name] = {
+                        "labels": timeserie_tags.copy(),
+                        "data": {datapoints_timestamp: metric_value},
+                    }
             else:
                 logging.warning(
-                    "Unable to find metric path {} in {}".format(jsonpath, results_dict)
+                    "Unable to find metric path {} in result dict".format(jsonpath)
                 )
-    return True, branch_time_series_dict
+    return branch_time_series_dict
 
 
 def get_project_ts_tags(
@@ -549,44 +625,26 @@ def extract_perbranch_timeseries_from_results(
     deployment_type: str,
     test_name: str,
     tf_triggering_env: str,
+    metadata_tags={},
+    build_variant_name=None,
 ):
-    branch_time_series_dict = {}
-    for jsonpath in metrics:
-        try:
-            jsonpath_expr = parse(jsonpath)
-        except Exception:
-            pass
-        finally:
-            metric_name = jsonpath[2:]
-            ts_name = get_ts_metric_name(
-                "by.branch",
-                tf_github_branch,
-                tf_github_org,
-                tf_github_repo,
-                deployment_type,
-                test_name,
-                tf_triggering_env,
-                metric_name,
-            )
-            find_res = jsonpath_expr.find(results_dict)
-            if find_res is not None and len(find_res) > 0:
-                metric_value = float(find_res[0].value)
-
-                branch_tags = get_project_ts_tags(
-                    tf_github_org, tf_github_repo, deployment_type, tf_triggering_env
-                )
-                branch_tags["branch"] = str(tf_github_branch)
-                branch_tags["test_name"] = str(test_name)
-                branch_tags["metric"] = str(metric_name)
-
-                branch_time_series_dict[ts_name] = {
-                    "labels": branch_tags.copy(),
-                    "data": {datapoints_timestamp: metric_value},
-                }
-            else:
-                logging.warning(
-                    "Unable to find metric path {} in {}".format(jsonpath, results_dict)
-                )
+    break_by_key = "branch"
+    break_by_str = "by.{}".format(break_by_key)
+    branch_time_series_dict = common_timeseries_extraction(
+        break_by_key,
+        break_by_str,
+        datapoints_timestamp,
+        deployment_type,
+        metrics,
+        tf_github_branch,
+        results_dict,
+        test_name,
+        tf_github_org,
+        tf_github_repo,
+        tf_triggering_env,
+        metadata_tags,
+        build_variant_name,
+    )
     return True, branch_time_series_dict
 
 
