@@ -218,17 +218,26 @@ def get_ts_metric_name(
     test_name,
     tf_triggering_env,
     metric_name,
+    metric_context_path=None,
+    use_metric_context_path=False,
+    build_variant_name=None,
 ):
+    if use_metric_context_path:
+        metric_name = "{}/{}".format(metric_name, metric_context_path)
+    build_variant_str = ""
+    if build_variant_name is not None:
+        build_variant_str = "{}/".format(str(build_variant_name))
     ts_name = (
         "ci.benchmarks.redislabs/{by}/"
         "{triggering_env}/{github_org}/{github_repo}/"
-        "{test_name}/{deployment_type}/{by_value}/{metric}".format(
+        "{test_name}/{build_variant_str}{deployment_type}/{by_value}/{metric}".format(
             by=by,
             triggering_env=tf_triggering_env,
             github_org=tf_github_org,
             github_repo=tf_github_repo,
             test_name=test_name,
             deployment_type=deployment_type,
+            build_variant_str=build_variant_str,
             by_value=str(by_value),
             metric=metric_name,
         )
@@ -236,7 +245,7 @@ def get_ts_metric_name(
     return ts_name
 
 
-def wait_for_conn(conn, retries=120, command="PING", should_be=True):
+def wait_for_conn(conn, retries=20, command="PING", should_be=True):
     """Wait until a given Redis connection is ready"""
     result = False
     while retries > 0 and result is False:
